@@ -1769,21 +1769,236 @@ class Pseudonym(Base):
 
 class Quiz(Base):
     """
-    Модель "Тест"
+    Контрольная работа
     """
-
     __tablename__ = 'quizzes'
 
+    # Идентификатор
     id = Column(Integer, primary_key=True)
+
+    # Наименование
     title = Column(String(255))
+
+    # Описание
+    description = Column(String)
+
+    # Данные контрольной работы
+    # В формате YAML
+    quiz_data = Column(String)
+
+    # Максимальный балл
+    points_possible = Column(Float)
+
+    # Идентификатор контекста
+    context_id = Column(Integer)
+
+    # Тип контекста
+    # Возможные значения:
+    # - Course (Курс)
+    context_type = Column(String(255))
+
+    @validates('context_type')
+    def validate_context_type(self, key, value):
+        """
+        Значением context_type могут быть следующие значения:
+        - Course (Курс)
+        """
+        assert value in ['Course']
+        return value
+
+    # Задание
     assignment_id = Column(ForeignKey('assignments.id'))
     assignment = relationship('Assignment')
 
+    # Статус
+    # Возможные значения:
+    # - active (Активный)
+    # - available (Доступный)
+    # - created (Создан)
+    # - deleted (Удален)
+    # - edited (Редактирован)
+    # - unpublished (Не опубликован)
+    workflow_state = Column(default='unpublished')
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state могут быть следующие значения:
+        - active (Активный)
+        - available (Доступный)
+        - created (Создан)
+        - deleted (Удален)
+        - edited (Редактирован)
+        - unpublished (Не опубликован)
+        """
+        assert value in ['active', 'available',
+                         'created', 'deleted', 'edited', 'unpublished']
+        return value
+
+    # Перемешать ответы (Рандом)
+    shuffle_answers = Column(Boolean, default=False)
+
+    # Показывать правильные ответы
+    show_correct_answers = Column(Boolean, default=False)
+
+    # Ограничение по-времени (в минутах)
+    time_limit = Column(Integer)
+
+    # Количество разрешенных попыток
+    allowed_attempts = Column(Integer, default=1)
+
+    # Какую оценку выбрать из всех попыток
+    # Возможные значения:
+    # - keep_average (Выбрать среднюю оценку)
+    # - keep_highest (Выбрать максимальную оценку)
+    # - keep_latest (Выбрать последнюю оценку)
+    scoring_policy = Column(String(255))
+
+    @validates('scoring_policy')
+    def validate_scoring_policy(self, key, value):
+        """
+        Значением scoring_policy могут быть следующие значения:
+        - keep_average (Выбрать среднюю оценку)
+        - keep_highest (Выбрать максимальную оценку)
+        - keep_latest (Выбрать последнюю оценку)
+        """
+        assert value in ['keep_average', 'keep_highest', 'keep_latest']
+        return value
+
+    # Тип контрольной работы
+    # Возможные значения:
+    # - assignment (Задание)
+    # - graded_survey (Оцениваемый опрос)
+    # - practice_quiz (???)
+    # - survey (Опрос)
+    quiz_type = Column(String(255))
+
+    @validates('quiz_type')
+    def validate_quiz_type(self, key, value):
+        """
+        Значением quiz_type могут быть следующие значения:
+        - assignment (Задание)
+        - graded_survey (Оцениваемый опрос)
+        - practice_quiz (???)
+        - survey (Опрос)
+        """
+        assert value in ['assignment',
+                         'graded_survey', 'practice_quiz', 'survey']
+        return value
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Дата и время "Доступен до"
+    lock_at = Column(DateTime)
+
+    # Дата и время "Доступен с"
+    unlock_at = Column(DateTime)
+
+    # Дата и время удаления
+    deleted_at = Column(DateTime)
+
+    @validates('deleted_at')
+    def validate_deleted_at(self, key, value):
+        if self.workflow_state == 'deleted':
+            assert value is not None
+        else:
+            assert value is None
+
+        return value
+
+    # Неизвестное поле
+    could_be_locked = Column(Boolean)
+
+    # Неизвестное поле
+    cloned_item_id = Column(Integer)
+
+    # Неизвестное поле
+    access_code = Column(String(255))
+
+    # Неизвестное поле
+    migration_id = Column(String(255))
+
+    # Количество неопубликованных вопросов
+    unpublished_question_count = Column(Integer)
+
+    # Дата и время - Срок
+    due_at = Column(DateTime)
+
+    # Количество вопросов
+    question_count = Column(Integer)
+
+    # Неизвестное поле
+    last_assignment_id = Column(Integer)
+
+    # Дата и время публикации
+    published_at = Column(DateTime)
+
+    # Дата и время редактирования
+    last_edited_at = Column(DateTime)
+
+    # Неизвестное поле
+    anonymous_submissions = Column(Boolean)
+
+    # Неизвестное поле
+    assignment_group_id = Column(Integer)
+
+    # Неизвестное поле
+    hide_results = Column(String(255))
+
+    # Неизвестное поле
+    ip_filter = Column(String(255))
+
+    # Неизвестное поле
+    require_lockdown_browser = Column(Boolean)
+
+    # Неизвестное поле
+    require_lockdown_browser_for_results = Column(Boolean)
+
+    # По одному вопросу
+    one_question_at_a_time = Column(Boolean)
+
+    # Неизвестное поле
+    cant_go_back = Column(Boolean)
+
+    # Показывать правильные ответы после даты и времени
+    show_correct_answers_at = Column(DateTime)
+
+    # Скрывать правильные ответы после даты и времени
+    hide_correct_answers_at = Column(DateTime)
+
+    # Неизвестное поле
+    require_lockdown_browser_monitor = Column(Boolean)
+
+    # Неизвестное поле
+    lockdown_browser_monitor_data = Column(String)
+
+    # Неизвестное поле
+    only_visible_to_overrides = Column(Boolean)
+
+    # Неизвестное поле
+    one_time_results = Column(Boolean)
+
+    # Неизвестное поле
+    show_correct_answers_last_attempt = Column(Boolean)
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
+    # Неизвестное поле
+    disable_timer_autosubmission = Column(Boolean)
+
     def __repr__(self):
-        return '<Quiz {} (id={})>'.format(self, self.id)
+        return f'<Quiz {self} (id={self.id} workflow_state={self.workflow_state})>'
 
     def __str__(self):
-        return self.name
+        return f'{self.name}'
 
 
 class Enrollment(Base):
@@ -1907,3 +2122,28 @@ class EnrollmentState(Base):
 
     def __str__(self):
         return str(self.enrollment)
+
+
+class YU_OverrideLink(Base):
+    """
+    Кастомная таблица для связи между группами из Univer и идентификатором Override
+    """
+    __tablename__ = 'yu_override_link'
+
+    # Идентификатор
+    id = Column(Integer, primary_key=True)
+
+    # Секция курса (Группа)
+    course_section = Column(String(255))
+
+    # Задание (Идентификатор)
+    assignment = Column(Integer)
+
+    # Override (Идентификатор)
+    override = Column(Integer)
+
+    def __repr__(self):
+        return f'<YU_OverrideLink {self} ({self.id})>'
+
+    def __str__(self):
+        return f'{self.course_section}: {self.assignment}'
